==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/routeequipment_001/RouteEquipment.java <==

package net.datastream.schemas.mp_entities.routeequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ROUTEEQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.ROUTEEQUIPMENTTYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTTYPE"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "routeequipmentid",
    "routeequipmenttype"
})
@XmlRootElement(name = "RouteEquipment")
public class RouteEquipment {

    @XmlElement(name = "ROUTEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTEEQUIPMENTID_Type routeequipmentid;
    @XmlElement(name = "ROUTEEQUIPMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTEEQUIPMENTTYPE_Type routeequipmenttype;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the routeequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link ROUTEEQUIPMENTID_Type }
     *     
     */
    public ROUTEEQUIPMENTID_Type getROUTEEQUIPMENTID() {
        return routeequipmentid;
    }

    /**
     * Sets the value of the routeequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTEEQUIPMENTID_Type }
     *     
     */
    public void setROUTEEQUIPMENTID(ROUTEEQUIPMENTID_Type value) {
        this.routeequipmentid = value;
    }

    /**
     * Gets the value of the routeequipmenttype property.
     * 
     * @return
     *     possible object is
     *     {@link ROUTEEQUIPMENTTYPE_Type }
     *     
     */
    public ROUTEEQUIPMENTTYPE_Type getROUTEEQUIPMENTTYPE() {
        return routeequipmenttype;
    }

    /**
     * Sets the value of the routeequipmenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTEEQUIPMENTTYPE_Type }
     *     
     */
    public void setROUTEEQUIPMENTTYPE(ROUTEEQUIPMENTTYPE_Type value) {
        this.routeequipmenttype = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_entities/routeequipment_001/RouteEquipment.java <==

package net.datastream.schemas.mp_entities.routeequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ROUTEEQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.ROUTEEQUIPMENTTYPE_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTTYPE"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "routeequipmentid",
    "routeequipmenttype"
})
@XmlRootElement(name = "RouteEquipment")
public class RouteEquipment {

    @XmlElement(name = "ROUTEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTEEQUIPMENTID_Type routeequipmentid;
    @XmlElement(name = "ROUTEEQUIPMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTEEQUIPMENTTYPE_Type routeequipmenttype;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété routeequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link ROUTEEQUIPMENTID_Type }
     *     
     */
    public ROUTEEQUIPMENTID_Type getROUTEEQUIPMENTID() {
        return routeequipmentid;
    }

    /**
     * Définit la valeur de la propriété routeequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTEEQUIPMENTID_Type }
     *     
     */
    public void setROUTEEQUIPMENTID(ROUTEEQUIPMENTID_Type value) {
        this.routeequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété routeequipmenttype.
     * 
     * @return
     *     possible object is
     *     {@link ROUTEEQUIPMENTTYPE_Type }
     *     
     */
    public ROUTEEQUIPMENTTYPE_Type getROUTEEQUIPMENTTYPE() {
        return routeequipmenttype;
    }

    /**
     * Définit la valeur de la propriété routeequipmenttype.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTEEQUIPMENTTYPE_Type }
     *     
     */
    public void setROUTEEQUIPMENTTYPE(ROUTEEQUIPMENTTYPE_Type value) {
        this.routeequipmenttype = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
